@@ -11,6 +11,13 @@
 #include <KQuickConfigModule>
 #include <QObject>
 
+struct DriverMatch {
+    QString ppd;
+    QString match;
+};
+
+typedef QList<DriverMatch> DriverMatchList;
+
 namespace PMTypes
 {
 Q_NAMESPACE
@@ -48,7 +55,7 @@ class PrinterManager : public KQuickConfigModule
     Q_PROPERTY(bool allowUserCancelAnyJobs READ allowUserCancelAnyJobs NOTIFY serverSettingsChanged)
 
 public:
-    PrinterManager(QObject *parent, const KPluginMetaData &metaData);
+    PrinterManager(QObject *parent, const KPluginMetaData &metaData, const QVariantList &args = QVariantList());
 
     Q_INVOKABLE void removePrinter(const QString &name);
 
@@ -60,8 +67,6 @@ public:
     Q_INVOKABLE void printSelfTestPage(const QString &name);
     Q_INVOKABLE void cleanPrintHeads(const QString &name);
 
-    Q_INVOKABLE void pausePrinter(const QString &name);
-    Q_INVOKABLE void resumePrinter(const QString &name);
     Q_INVOKABLE static bool isIPPCapable(const QString &uri);
     Q_INVOKABLE static bool isSCPAvailable();
 
@@ -87,13 +92,16 @@ public Q_SLOTS:
 Q_SIGNALS:
     void requestError(const QString &errorMessage);
     void removeDone();
-    void saveDone();
+    void saveDone(bool forceRefresh);
     void serverSettingsChanged();
     void serverStopped();
     void serverStarted();
     void remotePrintersLoaded();
     void recommendedDriversLoaded();
     void ppdLoaded(const QVariantMap &printerPPD);
+    void cmdAddPrinter();
+    void cmdAddGroup();
+    void cmdConfigurePrinter(const QString &name);
 
 private:
     KCupsRequest *setupRequest(std::function<void()> finished = []() { });
@@ -109,6 +117,10 @@ private:
     QVariantList m_recommendedDrivers;
     QString m_osName;
     QString m_osBugReportUrl;
+    void processCmdLine(const QVariantList &args);
 };
 
+Q_DECLARE_METATYPE(DriverMatchList)
+Q_DECLARE_METATYPE(DriverMatch)
+
 #endif
