@@ -91,10 +91,6 @@ PrinterModel::PrinterModel(QObject *parent)
     connect(KCupsConnection::global(), &KCupsConnection::serverStopped, this, &PrinterModel::serverChanged);
     connect(KCupsConnection::global(), &KCupsConnection::serverRestarted, this, &PrinterModel::serverChanged);
 
-    connect(this, &PrinterModel::rowsInserted, this, &PrinterModel::slotCountChanged);
-    connect(this, &PrinterModel::rowsRemoved, this, &PrinterModel::slotCountChanged);
-    connect(this, &PrinterModel::modelReset, this, &PrinterModel::slotCountChanged);
-
     update();
 }
 
@@ -194,11 +190,6 @@ bool PrinterModel::showLocations() const
     return m_showLocations;
 }
 
-void PrinterModel::slotCountChanged()
-{
-    Q_EMIT countChanged(rowCount());
-}
-
 QVariant PrinterModel::headerData(int section, Qt::Orientation orientation, int role) const
 {
     if (section == 0 && orientation == Qt::Horizontal && role == Qt::DisplayRole) {
@@ -207,9 +198,19 @@ QVariant PrinterModel::headerData(int section, Qt::Orientation orientation, int
     return QVariant();
 }
 
-int PrinterModel::count() const
+KCupsRequest *PrinterModel::setupRequest(std::function<void()> finished)
 {
-    return rowCount();
+    auto request = new KCupsRequest;
+    connect(request, &KCupsRequest::finished, this, [this, finished](KCupsRequest *r) {
+        if (r->hasError()) {
+            Q_EMIT error(r->error(), r->serverError(), r->errorMsg());
+        } else {
+            finished();
+        }
+        r->deleteLater();
+    });
+
+    return request;
 }
 
 bool PrinterModel::serverUnavailable() const
@@ -224,42 +225,14 @@ QHash<int, QByteArray> PrinterModel::roleNames() const
 
 void PrinterModel::pausePrinter(const QString &printerName)
 {
-    QPointer<KCupsRequest> request = new KCupsRequest;
+    const auto request = setupRequest();
     request->pausePrinter(printerName);
-    request->waitTillFinished();
-    if (request) {
-        request->deleteLater();
-    }
 }
 
 void PrinterModel::resumePrinter(const QString &printerName)
 {
-    QPointer<KCupsRequest> request = new KCupsRequest;
+    const auto request = setupRequest();
     request->resumePrinter(printerName);
-    request->waitTillFinished();
-    if (request) {
-        request->deleteLater();
-    }
-}
-
-void PrinterModel::rejectJobs(const QString &printerName)
-{
-    QPointer<KCupsRequest> request = new KCupsRequest;
-    request->rejectJobs(printerName);
-    request->waitTillFinished();
-    if (request) {
-        request->deleteLater();
-    }
-}
-
-void PrinterModel::acceptJobs(const QString &printerName)
-{
-    QPointer<KCupsRequest> request = new KCupsRequest;
-    request->acceptJobs(printerName);
-    request->waitTillFinished();
-    if (request) {
-        request->deleteLater();
-    }
 }
 
 void PrinterModel::update()
@@ -304,7 +277,6 @@ void PrinterModel::updateDest(QStandardItem *destItem, const KCupsPrinter &print
     if (state != destItem->data(DestState)) {
         destItem->setData(state, DestState);
     }
-    qCDebug(LIBKCUPS) << state << printer.name();
 
     // store if the printer is accepting jobs
     bool accepting = printer.isAcceptingJobs();
@@ -318,7 +290,7 @@ void PrinterModel::updateDest(QStandardItem *destItem, const KCupsPrinter &print
         destItem->setData(status, DestStatus);
     }
 
-    bool paused = (state == KCupsPrinter::Stopped || !accepting);
+    bool paused = (state == KCupsPrinter::Stopped);
     if (paused != destItem->data(DestIsPaused)) {
         destItem->setData(paused, DestIsPaused);
     }
