@@ -98,17 +98,9 @@ PrintQueueUi::PrintQueueUi(const KCupsPrinter &printer, QWidget *parent)
 
     QHeaderView *header = ui->jobsView->header();
     header->setSectionResizeMode(QHeaderView::Interactive);
-    header->setStretchLastSection(false);
-    header->setSectionResizeMode(JobModel::ColStatus, QHeaderView::ResizeToContents);
     header->setSectionResizeMode(JobModel::ColName, QHeaderView::Stretch);
-    header->setSectionResizeMode(JobModel::ColUser, QHeaderView::ResizeToContents);
-    header->setSectionResizeMode(JobModel::ColCreated, QHeaderView::ResizeToContents);
-    header->setSectionResizeMode(JobModel::ColCompleted, QHeaderView::ResizeToContents);
-    header->setSectionResizeMode(JobModel::ColPages, QHeaderView::ResizeToContents);
-    header->setSectionResizeMode(JobModel::ColProcessed, QHeaderView::ResizeToContents);
-    header->setSectionResizeMode(JobModel::ColSize, QHeaderView::ResizeToContents);
-    header->setSectionResizeMode(JobModel::ColStatusMessage, QHeaderView::ResizeToContents);
-    header->setSectionResizeMode(JobModel::ColPrinter, QHeaderView::ResizeToContents);
+    header->setSectionResizeMode(JobModel::ColStatus, QHeaderView::ResizeToContents);
+    header->setSectionResizeMode(JobModel::ColStatusMessage, QHeaderView::Stretch);
 
     KConfigGroup printQueue(KSharedConfig::openConfig(QLatin1String("print-manager")), QStringLiteral("PrintQueue"));
     if (printQueue.hasKey("ColumnState")) {
@@ -141,12 +133,6 @@ PrintQueueUi::PrintQueueUi(const KCupsPrinter &printer, QWidget *parent)
     // This is emitted when a printer is removed
     connect(KCupsConnection::global(), &KCupsConnection::printerDeleted, this, &PrintQueueUi::updatePrinter);
 
-    // This is emitted when a printer/queue is changed
-    // Deprecated stuff that works better than the above
-    connect(KCupsConnection::global(), &KCupsConnection::rhPrinterAdded, this, &PrintQueueUi::updatePrinterByName);
-    connect(KCupsConnection::global(), &KCupsConnection::rhPrinterRemoved, this, &PrintQueueUi::updatePrinterByName);
-    connect(KCupsConnection::global(), &KCupsConnection::rhQueueChanged, this, &PrintQueueUi::updatePrinterByName);
-
     updatePrinterByName(m_destName);
 
     // Restore the dialog size
@@ -381,7 +367,7 @@ void PrintQueueUi::getAttributesFinished(KCupsRequest *request)
         setEnabled(true);
     }
 
-    KCupsPrinter printer = request->printers().first();
+    KCupsPrinter printer = request->printers().at(0);
 
     // get printer-info
     if (printer.info().isEmpty()) {
